﻿ 

using System;
using System.Collections.Generic;
using System.Data;
using System.Data.Entity;
using System.Linq;
using System.Net;
using System.Web;
using System.Web.Mvc;
using JW_ScaffoldEnhancement.Models;
using JW_ScaffoldEnhancement.Data;

namespace JW_ScaffoldEnhancement.Controllers
{
    public class ProductController : Controller
    {
        private DataManagerContext db = new DataManagerContext();

        // GET: /Product/
        public ActionResult Index()
        {
            return View(db.Products.ToList());
        }

        // GET: /Product/Details/5
        public ActionResult Details(int? id)
        {
            if (id == null)
            {
                return new HttpStatusCodeResult(HttpStatusCode.BadRequest);
            }
            Product product = db.Products.Find(id);
            if (product == null)
            {
                return HttpNotFound();
            }
            return View(product);
        }

        // GET: /Product/Create
        public ActionResult Create()
        {
            return View();
        }

        // POST: /Product/Create
        // To protect from overposting attacks, please enable the specific properties you want to bind to, for 
        // more details see http://go.microsoft.com/fwlink/?LinkId=317598.
        [HttpPost]
        [ValidateAntiForgeryToken]
        public ActionResult Create([Bind(Include="ProductId,Description,CreatedDate,ModifiedDate")] Product product)
        {
            if (ModelState.IsValid)
            {
				// JW: To use the OnCreate extension, ensure your model implements IControllerHooks
				if (product is IControllerHooks) { ((IControllerHooks)product).OnCreate(); }
                db.Products.Add(product);
                db.SaveChanges();
                return RedirectToAction("Index");
            }

            return View(product);
        }

        // GET: /Product/Edit/5
        public ActionResult Edit(int? id)
        {
            if (id == null)
            {
                return new HttpStatusCodeResult(HttpStatusCode.BadRequest);
            }
            Product product = db.Products.Find(id);
            if (product == null)
            {
                return HttpNotFound();
            }
            return View(product);
        }

        // POST: /Product/Edit/5
        // To protect from overposting attacks, please enable the specific properties you want to bind to, for 
        // more details see http://go.microsoft.com/fwlink/?LinkId=317598.
        [HttpPost]
        [ValidateAntiForgeryToken]
        public ActionResult Edit([Bind(Include="ProductId,Description,CreatedDate,ModifiedDate")] Product product)
        {
            if (ModelState.IsValid)
            {
				// JW: To use the OnEdit extension, ensure your model implements IControllerHooks
				if (product is IControllerHooks) { ((IControllerHooks)product).OnEdit(); }

                db.Products.Attach(product);
				var productEntry = db.Entry(product);

				productEntry.Property(e => e.ProductId).IsModified = true;
				productEntry.Property(e => e.Description).IsModified = true;
				productEntry.Property(e => e.CreatedDate).IsModified = false;
				productEntry.Property(e => e.ModifiedDate).IsModified = true;

                db.SaveChanges();
                return RedirectToAction("Index");
            }
            return View(product);
        }

        // GET: /Product/Delete/5
        public ActionResult Delete(int? id)
        {
            if (id == null)
            {
                return new HttpStatusCodeResult(HttpStatusCode.BadRequest);
            }
            Product product = db.Products.Find(id);
            if (product == null)
            {
                return HttpNotFound();
            }
            return View(product);
        }

        // POST: /Product/Delete/5
        [HttpPost, ActionName("Delete")]
        [ValidateAntiForgeryToken]
        public ActionResult DeleteConfirmed(int id)
        {
            Product product = db.Products.Find(id);
            db.Products.Remove(product);
            db.SaveChanges();
            return RedirectToAction("Index");
        }

        protected override void Dispose(bool disposing)
        {
            if (disposing)
            {
                db.Dispose();
            }
            base.Dispose(disposing);
        }
    }
}
